# 更新
+ V0.1.5
  - 新增本地缓存机制
+ v0.1.6
  - 默认连接地址
+ v0.1.7
  - 映射host
+ v0.1.8
  - 调整相对路径
+ v0.1.9
  - 修改缓存配置
+ v0.1.10
  - 获取用户信息,本地缓存配置
+ v0.1.11
  - 用户头像字段调整
+ v0.1.12
  - 新增密码学登录
  - 新增修改密码
  - 支持重置社媒账号密码
+ v0.1.13
  - 包路径调整
+ v0.1.14
  - 新增facebook第三方登录
  - 新增邮箱注册功能
+ v0.1.15
  - 新增忘记密码
  - 新增找回密码
  - 新增账户注销
+ v0.1.16
  - 修改接口返回数据
+ v0.1.17
  - 用户注销调整
+ v0.1.18
  - 新增邮件发送功能